#!/bin/bash
# This script expects the most recent valid checkpoint to be available in
# $CHECKPOINTS in order for this script to work.
#
# This script is using the following external variables:
#
# SDP_INSTANCE - The instance of Perforce that is being backed up. Always an
# integer value.
#
# P4HOME - Server's home directory.
# P4BIN - Command line client name for the instance being backed up.
# P4DBIN - Server executable name for the instance being backed up.
# P4ROOT - Server's root directory. p4/root, p4_N/root
# P4PORT - TCP/IP port for the server instance being backed up.
# P4JOURNAL - Location of the Journal for the server instance being backed up.
#
#
export SDP_INSTANCE=${SDP_INSTANCE:-Undefined} 
export SDP_INSTANCE=${1:-$SDP_INSTANCE} 
if [[ $SDP_INSTANCE == Undefined ]]; then 
   echo "Instance parameter not supplied." 
   echo "You must supply the Perforce instance as a parameter to this script." 
   exit 1 
fi 

. /p4/common/bin/p4_vars $SDP_INSTANCE
. /p4/common/bin/backup_functions.sh
LOGFILE=${LOGS}/replica_cleanup.log

######### Start of Script ##########

check_vars
set_vars
get_journalnum
rotate_last_run_logs
log "Start $P4SERVER log cleanup"
check_uid
check_dirs
$P4CBIN/p4login 
remove_old_checkpoints_and_journals

if [[ -d ${P4HOME}/journals.rep ]]; then
   export CHECKPOINTS=${P4HOME}/journals.rep
   remove_old_checkpoints_and_journals
fi

remove_old_logs
log "End $P4SERVER log cleanup"
mail_log_file "$HOSTNAME $P4SERVER Daily log clean up."
