#!/bin/bash
#==============================================================================
# Copyright and license info is available in the LICENSE file included with
# the Server Deployment Package (SDP), and also available online:
# https://swarm.workshop.perforce.com/projects/perforce-software-sdp/view/main/LICENSE
#------------------------------------------------------------------------------
export SDP_INSTANCE=${SDP_INSTANCE:-Undefined} 
export SDP_INSTANCE=${1:-$SDP_INSTANCE} 
if [[ $SDP_INSTANCE == Undefined ]]; then 
   echo "Instance parameter not supplied." 
   echo "You must supply the Perforce instance as a parameter to this script." 
   exit 1 
fi 

ERRORTEXT=""

. /p4/common/bin/p4_vars $SDP_INSTANCE
. /p4/common/bin/backup_functions.sh

$P4CBIN/p4login

P4="$P4BIN -p ${P4PORT} -u $P4USER"

LOGFILE=$LOGS/replica_status.log

$P4 pull -lj > $LOGFILE 2>&1

if ( grep "Connection refused" $LOGFILE > /dev/null 2>&1 ); then
  ERRORTEXT="ERROR - The replica is offline!"
  echo $ERRORTEXT > $LOGFILE
fi

if ( grep "\-1" $LOGFILE > /dev/null 2>&1 ); then
  ERRORTEXT="ERROR - The replica is out of sync!"
fi

if ( grep -i "password" $LOGFILE > /dev/null 2>&1 ); then
  ERRORTEXT="ERROR - The admin user is not logged in!"
fi

mail_log_file "$ERRORTEXT $HOSTNAME $P4SERVER Daily Replica Status."
