#!/bin/bash
# Intended to be run on a replica machine to sync replica from its corresponding master
export SDP_INSTANCE=${SDP_INSTANCE:-Undefined} 
export SDP_INSTANCE=${1:-$SDP_INSTANCE} 
if [[ $SDP_INSTANCE == Undefined ]]; then 
   echo "Instance parameter not supplied." 
   echo "You must supply the Perforce instance as a parameter to this script." 
   exit 1 
fi 

. /p4/common/bin/p4_vars $SDP_INSTANCE
. /p4/common/bin/backup_functions.sh
LOGFILE=$LOGS/sync_replica.log

######### Start of Script ##########
check_vars
set_vars
get_journalnum
rotate_last_run_logs
log "Starting sync_replica.sh"

if [[ "${P4REPLICA}" == "FALSE" ]]; then
  die "Error: sync_replica can only be run a read only or forwarding replica." 
fi

check_uid

$P4CBIN/p4login_master
MASTERJOURNALNUM=$($P4BIN -u $P4USER -p ${P4MASTERPORT} counter journal)

if [[ "$MASTERJOURNALNUM" == "" ]]; then
   die "Error:  Couldn't get journal number from master.  Aborting."
fi

# We set JOURNALNUM to one less than the master since we are not truncating the journal
# and replay_journals_to_offline_db assumes that truncate_journal has been run.

JOURNALNUM=$(($MASTERJOURNALNUM-1))


# You must set up a public keypair using "ssh-keygen -t rsa" in order for this to work.
# You need to paste your CLIENT ~/.ssh/id_rsa.pub contents into the REMOTE ~/ssh/authorized_keys file. 
if [[ "$SHAREDDATA" == "FALSE" ]]; then
  rsync -avz --delete ${OSUSER}@${P4MASTER}:$CHECKPOINTS/ $CHECKPOINTS > $LOGFILE 2>&1
  rsync_exit_code=$?

  if [[ $rsync_exit_code -ne 0 ]]; then
    die "Error: Failed to pull $CHECKPOINTS from host $P4MASTER.  The rsync exit code was: $rsync_exit_code.  Aborting."
  fi
fi

recreate_offline_db_files
get_offline_journal_num
replay_journals_to_offline_db
$P4CBIN/p4login
remove_old_logs
export CHECKPOINTS=${P4HOME}/journals.rep
remove_old_checkpoints_and_journals
log "End $P4SERVER sync replica"
mail_log_file "$HOSTNAME $P4SERVER Daily sync replica log."
